==> lnl-2.1.10.tar.gz: lnl-2.1.10/src/amenu_prot.h <==
/* amenu.c */
void	init_auto_menu( void );
char	*menu_auto_mark( menu_t **pp, menu_t **dflt );
void	set_menu_auto_mark( menu_t **dflt );
char	*cb_menu_auto_mark_exec( menu_t **pp, menu_t **dflt );
void	set_auto_mark_cont( mbr_t *mbr );
bool_t	exec_menu_auto_mark( mbr_t *mbr );
bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr );
bool_t	exec_menu_auto_mark_item( mbr_t *mbr );
bool_t	exec_menu_auto_mark_door( mbr_t *mbr );
bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr );
char	*cb_menu_auto_mark_edit( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_edit_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_trgt_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_trgt( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_dist_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_dist( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_act( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_cond_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_cond( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_appoint_item(
	menu_t **pp, menu_t **dflt
);
char	*set_menu_auto_mark_appoint_item(
	menu_t *ls, long *k, char mjr_key,
	auto_mark_appoint_item_t **apo
);
char	*cb_menu_auto_mark_appoint_item_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_appoint_item_mnr(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_cont( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_priority( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_arrange( menu_t **pp, menu_t **dflt );
char	*get_msg_menu_auto_mark_edit_trgt( mbr_t *mbr );
char	*get_msg_menu_auto_mark_edit_dist( mbr_t *mbr );
char	*get_msg_menu_auto_mark_edit_act( mbr_t *mbr );
char	*get_msg_menu_auto_mark_edit_cond( mbr_t *mbr );
long	get_auto_mark_cur_n( void );

==> lnl-2.1.20.tar.gz: lnl-2.1.20/src/amenu_prot.h <==
/* amenu.c */
void	init_auto_menu( void );
void	init_auto_mark_all_mbr( void );
void	init_auto_mark_mbr( long ls_mbr_n );
char	*menu_auto_mark( menu_t **pp, menu_t **dflt );
void	set_menu_auto_mark( menu_t **dflt );
char	*cb_menu_auto_mark_exec( menu_t **pp, menu_t **dflt );
void	set_auto_mark_cont( mbr_t *mbr );
bool_t	exec_menu_auto_mark( mbr_t *mbr );
bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr );
bool_t	exec_menu_auto_mark_item( mbr_t *mbr );
bool_t	exec_menu_auto_mark_door( mbr_t *mbr );
bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr );
char	*cb_menu_auto_mark_edit( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_edit_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_trgt_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_trgt( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_dist_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_dist( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_act( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_cond_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_cond( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_appoint_item(
	menu_t **pp, menu_t **dflt
);
char	*set_menu_auto_mark_appoint_item(
	menu_t *ls, long *k, char mjr_key,
	auto_mark_appoint_item_t **apo
);
char	*cb_menu_auto_mark_appoint_item_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_appoint_item_mnr(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_cont( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_priority( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_arrange( menu_t **pp, menu_t **dflt );
char	*get_msg_menu_auto_mark_edit_trgt( mbr_t *mbr );
char	*get_msg_menu_auto_mark_edit_dist( mbr_t *mbr );
char	*get_msg_menu_auto_mark_edit_act( mbr_t *mbr );
char	*get_msg_menu_auto_mark_edit_cond( mbr_t *mbr );
long	get_auto_mark_cur_n( void );
auto_mark_appoint_item_t	*get_auto_mark_appoint_item( mbr_t *mbr );
char	*get_msg_ttl_auto_mark( long n );
